@@ -5,7 +5,7 @@ use strict;
 use HTTP::Tiny;
 use JSON::PP qw();
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 sub new {
 	my ($class,$args) = @_;
@@ -88,8 +88,9 @@ The following is example usage to verify captcha response.
 
 	my $cap = Captcha::noCAPTCHA->new({site_key => "your site key",secret_key => "your secret key"});
 	my $cgi = CGI->new;
+	my $captcha_response = $cgi->param('g-recaptcha-response');
 
-	if ($cap->verify($cgi->param('g-captcha-response',$cgi->address)) {
+	if ($cap->verify($captcha_response',$cgi->remote_host)) {
 		# Process the rest of the form.
 	} else {
 		# Tell user he/she needs to prove his/her humanity.
@@ -145,6 +146,10 @@ See it in action at L<https://www.httpuptime.com>
 
 Chuck Larson C<< <clarson@cpan.org> >>
 
+=head1 CONTRIBUTORS
+
+leejo C<< <leejo@cpan.org> >>
+
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2015, Chuck Larson C<< <chuck+github@endcapsoftwware.com> >>
